==> corestats-4.3.0.tar.gz: corestats-v4.3.0/src/main.cpp <==
/*
    *
    * This file is a part of CoreStats.
    * A real time system resource viewer for C Suite.
    * Copyright 2019 CuboCore Group
    *

    *
    * This program is free software; you can redistribute it and/or modify
    * it under the terms of the GNU General Public License as published by
    * the Free Software Foundation; either version 3 of the License, or
    * (at your option) any later version.
    *

    *
    * This program is distributed in the hope that it will be useful,
    * but WITHOUT ANY WARRANTY; without even the implied warranty of
    * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    * GNU General Public License for more details.
    *

    *
    * You should have received a copy of the GNU General Public License
    * along with this program; if not, write to the Free Software
    * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
    * MA 02110-1301, USA.
    *
*/


#include <cprime/capplication.h>
#include "corestats.h"

int main(int argc, char *argv[])
{
    QApplication::setAttribute(Qt::AA_EnableHighDpiScaling);

    CPrime::CApplication app("CoreStats", argc, argv);

    if (app.isRunning()) {
        return not app.sendMessage("");
    }

    // Set application info
    app.setOrganizationName("CuboCore");
    app.setApplicationName("CoreStats");
    app.setApplicationVersion(QStringLiteral(VERSION_TEXT));
    app.setDesktopFileName("org.cubocore.CoreStats.desktop");
    app.setQuitOnLastWindowClosed(true);

    corestats s;
    QObject::connect(&app, &CPrime::CApplication::messageReceived, [&s]() {
        s.show();
        s.activateWindow();
    });
    s.show();

    return app.exec();
}

==> corestats-4.5.0.tar.gz: corestats-v4.5.0/src/main.cpp <==
/*
    *
    * This file is a part of CoreStats.
    * A real time system resource viewer for C Suite.
    * Copyright 2019 CuboCore Group
    *

    *
    * This program is free software; you can redistribute it and/or modify
    * it under the terms of the GNU General Public License as published by
    * the Free Software Foundation; either version 3 of the License, or
    * (at your option) any later version.
    *

    *
    * This program is distributed in the hope that it will be useful,
    * but WITHOUT ANY WARRANTY; without even the implied warranty of
    * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    * GNU General Public License for more details.
    *

    *
    * You should have received a copy of the GNU General Public License
    * along with this program; if not, write to the Free Software
    * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
    * MA 02110-1301, USA.
    *
*/

#include <cprime/capplication.h>
#include "corestats.h"

#include <QMessageBox>

int main(int argc, char *argv[])
{
    QApplication::setAttribute(Qt::AA_EnableHighDpiScaling);

    CPrime::CApplication app("CoreStats", argc, argv);

    if (app.isRunning()) {
		return not app.sendMessage("App is already running. Using existing Instance.");
    }

    // Set application info
    app.setOrganizationName("CuboCore");
    app.setApplicationName("CoreStats");
    app.setApplicationVersion(QStringLiteral(VERSION_TEXT));
    app.setDesktopFileName("org.cubocore.CoreStats.desktop");
    app.setQuitOnLastWindowClosed(true);

    corestats s;
	QObject::connect(&app, &CPrime::CApplication::messageReceived, [&s](const QString &message) {
		QMessageBox::information(&s, qApp->applicationName(), message);
        s.show();
        s.activateWindow();
    });
    s.show();

    return app.exec();
}
